import type {
  AddViewConfig,
  FormValues,
  SchoolClassDetailResponseModel,
} from '../models';
import {fetchAuthenticated} from '../retrieveData';
import {getDetailResponseModelMocked} from '../dataAccess';


// eslint-disable-next-line
export const fetchSchoolClassAddViewConfig = async(): Promise<AddViewConfig | null> => {
  console.log('Not implemented');
  return null;
};

// eslint-disable-next-line
export const createSchoolClass = async(values: FormValues): Promise<boolean> => {
  console.log('Not implemented');
  return false;
};

const fetchSchoolClassMocked = (): SchoolClassDetailResponseModel => {
  const schoolClass: SchoolClassDetailResponseModel = getDetailResponseModelMocked();
  console.debug('mock school class', schoolClass);
  return schoolClass;
};

export const fetchSchoolClass = async(schoolClass: string): Promise<SchoolClassDetailResponseModel | null> => {
  if (import.meta.env.VITE_USE_REAL_BACKEND !== 'true') {
    console.debug('fetchSchoolClass. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data');
    return new Promise(resolve => {
      setTimeout(() => {
        resolve(fetchSchoolClassMocked());
      }, 1000);
    });
  }

  const answer = await fetchAuthenticated(`/ucsschool/bff-groups/v1/groups/school_class/detail/${schoolClass}`);
  if (!answer.ok) {
    // FIXME differentiate between 404 (school class does not exist) and other (backend failed in some way)
    // ... and other error cases (e.g. login token expired?)
    return null;
  }
  return await answer.json();
};

export const updateSchoolClass = async(url: string, values: FormValues): Promise<string> => {
  if (import.meta.env.VITE_USE_REAL_BACKEND !== 'true') {
    console.debug('updateSchoolClass. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data');
    // TODO have the fail case in some way too
    return new Promise(resolve => {
      setTimeout(() => {
        resolve('');
      }, 1000);
    });
  }

  const fixedProtocolUrl = url.replace(/https?:/, location.protocol).replace('detail/', '');
  const answer = await fetchAuthenticated(`${fixedProtocolUrl}`, {
    method: 'PATCH',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(values),
  });

  if (!answer.ok) {
    if (answer.status === 404) {
      return 'dataAccess.updateSchoolClass.error.404';
    }
    if (answer.status >= 500 && answer.status < 600) {
      return 'dataAccess.updateSchoolClass.error.5xx';
    }
    if (answer.status >= 400 && answer.status < 500) {
      return 'dataAccess.updateSchoolClass.error.4xx';
    }
  }
  return '';
};
